![GW150914](https://raw.githubusercontent.com/gwastro/pycbc-logo/master/pycbc_logo_name.png)

Welcome to PyCBC, a python toolkit for gravitational-wave astronomy and data analysis with the goal of detecting and studying gravitational waves from compact binary coalescences (CBCs) and other sources.

The PyCBC home page is located on github at

 * https://pycbc.org/

Documentation is automatically built nightly and available from

 * https://pycbc.org/pycbc/latest/html/

For the detailed installation instructions of PyCBC

 * https://pycbc.org/pycbc/latest/html/install.html
 
Want to get going using PyCBC?

 * [Try out our tutorials](https://github.com/gwastro/PyCBC-Tutorials). No software installation required and these can run entirely from the browser. 

Quick Installation
```
pip install lalsuite pycbc
```

If you use any code from PyCBC in a scientific publication, then please see our [citation guidelines](http://pycbc.org/pycbc/latest/html/credit.html) for more details on how to cite pycbc algorithms and
programs.

For the citation of the ``pycbc library``,  please use a bibtex entry and DOI for the
appropriate release of the PyCBC software (or the latest available release).
A bibtex key and DOI for each release is avaliable from [Zenodo](http://zenodo.org/).

[![DOI](https://zenodo.org/badge/31596861.svg)](https://zenodo.org/badge/latestdoi/31596861) [![Build Status](https://travis-ci.org/gwastro/pycbc.svg?branch=master)](https://travis-ci.org/gwastro/pycbc)  
[![PyPI version](https://badge.fury.io/py/PyCBC.svg)](https://badge.fury.io/py/PyCBC) ![PyPI - Downloads](https://img.shields.io/pypi/dm/pycbc) [![Anaconda-Server Badge](https://anaconda.org/conda-forge/pycbc/badges/version.svg)](https://anaconda.org/conda-forge/pycbc) [![Anaconda-Server Badge](https://anaconda.org/conda-forge/pycbc/badges/downloads.svg)](https://anaconda.org/conda-forge/pycbc)  
